/*
spinapi.h
*/

//Defines for start_programming
#define PULSE_PROGRAM 0
#define FREQ_REGS 1
#define PHASE_REGS 2
#define TX_PHASE_REGS 2
#define RX_PHASE_REGS 3
#define PHASE_REGS_0 3
#define PHASE_REGS_1 2


//Defines for enabling analog output
#define ANALOG_ON 1
#define ANALOG_OFF 0
#define TX_ANALOG_ON 1
#define TX_ANALOG_OFF 0
#define RX_ANALOG_ON 1
#define RX_ANALOG_OFF 0

//Defines for different pb_inst instruction types
#define CONTINUE 0
#define STOP 1
#define LOOP 2
#define END_LOOP 3
#define JSR 4
#define RTS 5
#define BRANCH 6
#define LONG_DELAY 7
#define WAIT 8

//Defines for using different units of time
#define ns 1.0
#define us 1000.0
#define ms 1000000.0
#define s 1000000000.0

//Defines for using different units of frequency
#define MHz 1.0
#define kHz .001
#define Hz .000001

#define PARAM_ERROR -99

//Variables for max number of registers (Currently the same across models)
#define MAX_PHASE_REGS 16
#define MAX_FREQ_REGS 16

//which os
#define WINDOWS

//if building windows dll, compile with -DDLL_EXPORTS flag
//if building code to use windows dll, no -D flag necessary
#ifdef WINDOWS
#ifdef DLL_EXPORTS
#define SPINCORE_API __declspec(dllexport)
#else
#define SPINCORE_API __declspec(dllimport)
#endif
#endif

///////////////////
// Exported Functions by spincore_api ... calls os-specific functions
// add a an exported fuction defintion here and its implementation in spincore_api.c
SPINCORE_API int pb_init();
SPINCORE_API int pb_close();
SPINCORE_API int pb_outp(unsigned int address, char data);
SPINCORE_API char pb_inp(unsigned int address);
SPINCORE_API int start_programming(int device);
SPINCORE_API int stop_programming();
SPINCORE_API int start_pb();
SPINCORE_API int stop_pb();
SPINCORE_API int pb_inst_tworf(int freq, int tx_phase, int tx_output_enable, int rx_phase, int rx_output_enable, int flags, int inst, int inst_data, double length);
SPINCORE_API int pb_inst_onerf(int freq, int phase, int rf_output_enable, int flags, int inst, int inst_data, double length);
SPINCORE_API int pb_inst_pbonly(int flags, int inst, int inst_data, double length);
SPINCORE_API void set_clock(double clock_freq);
SPINCORE_API void set_port_base(int new_port_base);
SPINCORE_API void set_ISA_address(int address);
SPINCORE_API int set_freq(double freq);
SPINCORE_API int set_phase(double phase);
SPINCORE_API int read_status();


#ifdef SP2
#define pb_inst pb_inst_pbonly
#endif

#ifdef SP3
#define pb_inst pb_inst_tworf
#endif

#ifdef SP4
#define bp_inst pb_inst_pbonly
#endif

